//
//  accessDB.h
//  ArticleDB
//
//  Created by Toshihiro Aoyama on Tue Jul 27 2004.
//  Copyright (c) 2004-2005 Toshihiro Aoyama. All rights reserved.
//

#import <Foundation/Foundation.h>

#import <QuickLite/QuickLiteDatabase.h>
#import <QuickLite/QuickLiteCursor.h>
#import <QuickLite/QuickLiteDatabaseExtras.h>

#import "Article.h"

@interface accessDB : NSObject {
@private
	QuickLiteDatabase* _database;

	NSTextField*      _status;
	NSProgressIndicator* _indicator;
	
	NSString* _fetchInfo;
	NSString* _orderInfo;
	NSMutableDictionary* _importFilenames;

	id recieverOfArticles;
	SEL recieverSelector;

	id recievedObject;
}
+ (id) instance;
- (NSNumber*)articleID:(Article*)anArticle;
- (NSNumber*)newArticleID;

- (BOOL)haveArticleWithArticleID:(NSNumber*)articleID;

- (void)setRecieverOfArticles:(id)rec;
- (void)setRecieverSelector:(SEL)selector;

- (void)createDB:(NSString*)dbFileName;
- (void)createAnnotationDB;
- (BOOL)insertArticle:(Article*)anArticleInfo;

- (void)createIndex;
- (NSNumber*)newUserID;

- (void)articlesForSearchKeyWithSpotlight:(NSString*)keyword;

- (void)setStatus:(NSTextField*)s;
- (void)setIndicator:(NSProgressIndicator*)i;

- (NSArray*)aritlceInformations:(QuickLiteCursor*)result from:(int)from to:(int)to;
- (void)divideArticles:(QuickLiteCursor*) result;

- (void)runQuery:(NSString*)query;

- (void)setMark:(NSString*)mark articleID:(NSNumber*)articleID;
- (void)setMemo:(NSString*)memo articleID:(NSNumber*)articleID;
- (void)setRate:(NSNumber*)rate articleID:(NSNumber*)articleID;

- (void)removeArticles:(NSArray*)articles;
- (BOOL)updateArticle:(NSDictionary*)anArticleInfo;

// Journal View
- (NSNumber*)journalIDofArticleID:(NSNumber*)articleID;
- (NSNumber*)journalID:(NSString*)journal;
- (NSArray*)initialsOfJournal;
- (NSArray*)journals;
- (NSArray*)journals:(NSString*)initial;
- (NSArray*)yearsInJournal:(NSString*)journal;

- (void)articlesInJournalInitial:(NSString*)initial;
- (void)articlesInJournal:(NSString*)journal;
- (void)articlesInJournal:(NSString*)journal year:(NSString*)year;
- (unsigned)numberOfArticlesInJournalInitial:(NSString*)initial;
- (unsigned)numberOfArticlesInJournal:(NSString*)journal;
- (unsigned)numberOfArticlesInJournal:(NSString*)journal year:(NSString*)year;

// Author View
- (NSArray*)authorsArrayFromAuthorsString:(NSString*)authors;

- (NSArray*)authorIDsOfArticle:(NSNumber*)articleID;
- (NSNumber*)authorID:(NSString*)author;
- (NSArray*)initialsOfAuthor;
- (NSArray*)authors;
- (NSArray*)authorsOfArticleID:(NSNumber*)articleID;
- (NSArray*)authors:(NSString*)initial;
- (NSArray*)yearsInAuthor:(NSString*)author;

- (void)articlesInAuthorInitial:(NSString*)initial;
- (void)articlesInAuthor:(NSString*)author;
- (void)articlesInAuthor:(NSString*)author year:(NSString*)year;
- (unsigned)numberOfArticlesInAuthorInitial:(NSString*)initial;
- (unsigned)numberOfArticlesInAuthor:(NSString*)author;
- (unsigned)numberOfArticlesInAuthor:(NSString*)author year:(NSString*)year;

//// MeshHeading
- (NSArray*)meshKeywordOfArticle:(NSNumber*)articleID;

- (NSArray*)meshIDsOfArticle:(NSNumber*)articleID;
- (NSNumber*)meshHeadingID:(NSString*)meshHeading;
- (NSArray*)initialsOfMeshHeading;
- (NSArray*)meshHeading:(NSString*)initial;
- (NSArray*)yearsInMeshHeading:(NSString*)meshHeading;
- (NSArray*)insertMeshHeadings:(NSArray*)meshHeadings;
- (void)insertMeshHeadingLookup:(NSArray*)meshIDs articleID:(NSNumber*)articleID;

- (void)articlesInMeshHeadingInitial:(NSString*)initial;
- (void)articlesInMeshHeading:(NSString*)mesh;
- (void)articlesInMeshHeading:(NSString*)mesh year:(NSString*)year;
- (unsigned)numberOfArticlesInMeshHeadingInitial:(NSString*)initial;
- (unsigned)numberOfArticlesInMeshHeading:(NSString*)mesh;
- (unsigned)numberOfArticlesInMeshHeading:(NSString*)mesh year:(NSString*)year;

////
- (void)allArticlesList;
- (unsigned)numberOfAllArticles;
- (void)articlesOfList:(NSArray*)articlesList;
- (void)articlesForQuery:(NSString*)query;

- (void)articlesForSearchKey:(NSString*)keyword;
- (unsigned)numberOfArticlesForSearchKey:(NSString*)keyword;
- (void)articlesForSearchKeyInLists:(NSArray*)array keyword:(NSString*)keyword;
- (unsigned)numberOfArticlesForSearchKeyInLists:(NSArray*)array keyword:(NSString*)keyword;

- (NSArray*)articleListsForQuery:(NSString*)whereQuery;

- (NSMutableString*)filepathOfArticle:(NSNumber*)articleID;
- (NSMutableString*)abstractOfArticle:(NSNumber*)articleID;
- (NSMutableString*)memoOfArticle:(NSNumber*)articleID;

- (NSArray*)arrayOfArticlesOfList:(NSArray*)articlesIDList;

- (BOOL)createFolder:(NSString*)creatingPath;
- (NSString*)copySupplementFileToFolder:(NSString*)fullpath articleID:(NSNumber*)articleID;
- (NSString*)removeSupplementFileFromFolder:(NSString*)fullpath articleID:(NSNumber*)articleID;
- (NSArray*)supplementFiles:(NSNumber*)articleID;
- (void)updateSupplementFiles:(NSArray*)files articleID:(NSNumber*)articleID;

// annotations
- (BOOL)setAnnotations:(NSArray*)annotations articleID:(NSNumber*)articleID;
- (NSArray*)annotations:(NSNumber*)articleID;
@end
