/* ArticleViewController */

#import <Cocoa/Cocoa.h>
#import <Quartz/Quartz.h>

#import "IPapersSplitView.h"
#import "IPapersTabView.h"
#import "Library.h"
#import "ArticleTableView.h"
#import "ArticleDrawerController.h"
#import "ImportPanelController.h"
#import "IPaperPDFViewController.h"

@interface LibraryViewController : NSObject
{
@private
	IBOutlet ArticleTableView*		_articleView;
	IBOutlet NSView*				_mainView;
	IBOutlet NSBrowser*				_journalBrowser;
	IBOutlet NSBrowser*				_authorBrowser;
	IBOutlet NSBrowser*				_meshBrowser;
	IBOutlet IPapersTabView*		_authorJournalTab;
	IBOutlet IPapersSplitView*		_mainSplitView;
	IBOutlet IPapersSplitView*		_articleSplitView;
	IBOutlet NSProgressIndicator*	_progressIndicator;
	IBOutlet NSTextField*			_status;
	IBOutlet NSTextView*			_contentsView;

	NSDrawer*		_drawer;
	IBOutlet NSView*			_drawerContents;

	IBOutlet IPaperPDFViewController*	_pdfViewController;
	
	IBOutlet ArticleDrawerController* _articleDrawerController;
	IBOutlet ImportPanelController* _importPanelController;
	
	NSMutableArray* initials;
	NSMutableArray* names;
	NSMutableArray* years;
	
// local class
	Source* _selectedSource;
	Library* _library;
// 
	NSDictionary* u8SpecialChar_to_ascii;
	NSDictionary* u8SpecialChar_to_tex;
	NSDictionary* pubmed_to_isoAbbrev;

	float TopHeight;
	float BottomHeight;
	BOOL isCollapsed;
//
	NSMutableArray*	articles;
	NSMutableArray* sortDescriptor;
	
	int numberOfMatchArticles;
	
	id recieveObject;
	NSLock* theLock;
	
	int openRow;
}
//- (void)setSearchField:(NSSearchField*)_SearchField;
- (void)setLibrary:(Library*)lib;

//
- (void)setSource:(Source*)selectedSource;
- (void)setNumberOfMatchArticles:(unsigned)n;

- (void)setDrawer:(NSDrawer*)d;
- (NSView*)libraryView;
- (void)initializeController;
- (void)updateView;
- (void)setSortDescriptor:(NSMutableArray*)sortDesc;

- (void)updateViewWithNotification:(NSNotification*)notification;

- (NSArray*)articlesInfo;
- (NSView*)mainView;
- (ArticleTableView*)articleView;
- (int)countOfCurrentArticles;

- (void)setMark:(id)sender mark:(NSString*)mark;
- (void)setImportantMark:(id)sender;
- (void)setQuestionMark:(id)sender;
- (void)setReadMark:(id)sender;
- (void)setUnMark:(id)sender;

- (void)removeArticles;

// local function
- (void)collapsed:(BOOL)flag;
- (void)appendArticles:(NSArray*)array;
- (void)resetArticleTable;
// string substitution from pubmed to tex
- (NSDictionary*) getU8SpecialChar_to_ascii;
- (NSDictionary*) getU8SpecialChar_to_tex;
- (NSDictionary*) getPubmed_to_isoAbbrev;
- (NSString*) stringU8_to_ascii:(NSString*)u8String;
- (NSString*) stringU8_to_tex:(NSString*)u8String;
- (NSString*) stringAuthorName:(NSString*)authorName;
- (NSString*) stringJournalName:(NSString*)src;

// IBAction
- (void)openFile:(id)sender;
- (IBAction)openContents:(id)sender;
- (IBAction)openInfo:(id)sender;
- (IBAction)openFinder:(id)sender;
- (IBAction)click:(id)sender;
- (IBAction)openImportPanel:(id)sender;
- (IBAction)toggleDrawer:(id)sender;
- (IBAction)copyInfo:(id)sender;
- (IBAction)copyID:(id)sender;

//
- (void)exportAsCSV:(id)sender;
- (void)exportAsEndNoteText:(id)sender;
- (void)exportAsBibTeX:(id)sender;
- (void)exportAsTheVancouverStyle:(id)sender;
@end
